@@ -9,10 +9,10 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.0.9"
+version = "1.1.3"
 global log
 global anon
-anon = "vpn"
+anon = "tor"
 log = False
 
 class ip:
@@ -171,7 +171,6 @@ class ip:
         print(yellow+bold+"        Developer: Misha Korzhik "+clear)
         print(yellow+bold+"           Tool Version: "+version+" \n"+clear)
         a = lgreen+bold+"["+clear+"+"+lgreen+bold+"]"+clear
-        # http(s)
         r01 = url.replace("https://", "http://")
         url = r01.replace("http://http://", "http://")
         res=requests.get(url, stream=True, headers=headers)
@@ -179,16 +178,33 @@ class ip:
         res2=url + " : " + str(ip)
         print(a, "┌──────────[Domain Ip]")
         print(a, "└ "+url[7:] + " : " + str(ip))
-    def proxy():
-        proxy_list = pyproxify.fetch(count=3, google=True, https=True)
-        for item in proxy_list:
-           print("Ip         : "+item["ip"])
-           print("Port       : "+item["port"])
-           print("Google     : True")
-           print("Https      : True")
-           print("Checked    : "+item["last_update"])
-           print("Anonymity  : "+item["anonymity"])
-           print(" ")
+    def proxy(data=False):
+        if data:
+           proxy_list = pyproxify.fetch(count=10, google=True, https=True)
+           proxy = []
+           for item in proxy_list:
+              ip = item["ip"]
+              port = item["port"]
+              proxy.append(ip+":"+port)
+           return proxy
+        else:
+           proxy_list = pyproxify.fetch(count=3, google=True, https=True)
+           for item in proxy_list:
+              ip = item["ip"]
+              port = item["port"]
+              last = item["last_update"]
+              anonymity = item["anonymity"]
+              country = item["country"]
+              c_name = country["name"]
+              print("Ip         : "+ip)
+              print("Port       : "+port)
+              print("Http       : True")
+              print("Https      : False")
+              print("Google     : True")
+              print("Country    : "+c_name)
+              print("Checked    : "+last)
+              print("Anonymity  : "+anonymity)
+              print(" ")
 
 class inquiry:
     def get(*args, **kwargs):
@@ -647,11 +663,14 @@ class inquiry:
            log = False
        else:
            log = True
-    def rechange():
+    def rechange(type="tor"):
        global anon
-       if anon == "vpn":
+       if type == "vpn" or type == "Vpn" or type == "VPN":
+           anon = "vpn"
+           return "Using: vpn"
+       elif type == "tor" or type == "TOR" or type == "Tor":
            anon = "tor"
            return "Using: tor"
        else:
-           anon = "vpn"
-           return "Using: vpn"
+           anon = "tor"
+           return "Unknown type: "+type+", defaul tor"
